@@ -9,6 +9,8 @@
 -------------------------------------------------
 """
 import collections
+import copy
+import glob
 import json
 import os
 import pickle
@@ -161,7 +163,7 @@ def table2json(path, **kwargs):
 
 
 # 将list数据存储成table格式
-def dump2table(data, path):
+def dump2table(data, path:str):
     if isinstance(data, list):
         data = pd.DataFrame.from_records(data)
     assert isinstance(data, pd.DataFrame)
@@ -200,39 +202,42 @@ def read2list(file_path: Union[str, List], **kwargs) -> List[Union[str, dict]]:
         if suffix in [".txt"]:
             return load_lines(file_path, **kwargs)
         else:
-            logger.warn(f"unknown suffix:{suffix}, read as txt")
+            logger.warning(f"unknown suffix:{suffix}, read as txt")
             return load_lines(file_path, **kwargs)
+    if isinstance(file_path, str):
+        file_path = glob.glob(file_path) if "*" in file_path else [file_path]
+
+    rs = []
+    for f in file_path:
+        logger.info(f"reading file_path={f}")
+        rs.extend(_read2list(f, **kwargs))
+    return rs
 
-    if isinstance(file_path, list):
-        rs = []
-        for f in file_path:
-            logger.info(f"reading file_path={f}")
-            rs.extend(_read2list(f, **kwargs))
-        return rs
-    else:
-        return _read2list(file_path=file_path, **kwargs)
 
 
 # 将list数据按照后缀名格式dump到文件
 def dump2list(data: List, file_path: str, **kwargs):
     create_dir_path(file_path)
-    surfix = os.path.splitext(file_path)[-1].lower()
-    if surfix == ".json":
+    suffix = os.path.splitext(file_path)[-1].lower()
+    if suffix == ".json":
         return jdump(data, file_path, **kwargs)
-    if surfix == ".jsonl":
+    if suffix == ".jsonl":
         return jdump_lines(data, file_path, **kwargs)
-    if surfix in [".xlsx", ".csv"]:
+    if suffix in [".xlsx", ".csv"]:
         return dump2table(data, file_path)
-    if surfix in [".txt"]:
+    if suffix in [".txt"]:
         return dump_lines(data, file_path, **kwargs)
     else:
-        logger.warn(f"unkown surfix:{surfix}, dump as txt")
+        logger.warning(f"unknown suffix:{suffix}, dump as txt")
         return dump_lines(data, file_path, **kwargs)
 
 
 dump_list = dump2list
 load2list = read2list
 
+dump = dump2list
+load = read2list
+
 # 递归将obj中的float做精度截断
 
 
@@ -247,7 +252,16 @@ def pretty_floats(obj, r=4):
 
 
 # 将data batch化输出
-def get_batched_data(data: Sequence, batch_size: int):
+def get_batched_data(data: Iterable, batch_size: int)->Iterable[List]:
+    """将数据按照batch_size分组
+
+    Args:
+        data (Iterable): 待分组数据
+        batch_size (int): 分组大小
+
+    Yields:
+        _type_: batch数据
+    """
     batch = []
     for item in data:
         batch.append(item)
@@ -344,6 +358,8 @@ def get_latest_version(package_name: str) -> str:
     pattern = "\(from versions:(.*?)\)"
 
     for item in re.findall(pattern, output):
+        if item is None:
+            return "0.0.1"
 
         # item
         versions = [tuple(int(i) for i in e.strip().split("."))
@@ -363,3 +379,35 @@ def get_next_version(version: str, level=0) -> str:
     else:
         pieces[idx] = str(int(val)+1)
     return ".".join(pieces)
+
+
+
+def deep_update(origin:dict, new_data:dict, inplace=True)->dict:
+    """递归跟新dict
+
+    Args:
+        origin (dict): 原始dict
+        new_data (dict): 需要更新的数据
+        inplace (bool, optional): 是否在原dict上直接修改. Defaults to True.
+
+    Returns:
+        dict: 更新后的dict
+    """
+    to_update = origin if inplace else copy.deepcopy(origin)
+    
+    def _deep_update_inplace(tu:dict, nd:dict)->dict:
+        for k,v in nd.items():
+            if k not in to_update:
+                tu[k] = v
+            else:
+                if isinstance(v, dict) and isinstance(to_update[k], dict):
+                    _deep_update_inplace(to_update[k], v)
+                else:
+                    tu[k] =v
+        return tu            
+    return _deep_update_inplace(to_update, new_data)
+    
+        
+            
+    
+    
\ No newline at end of file
